You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@directory.apache.org by ka...@apache.org on 2010/03/15 23:04:44 UTC

svn commit: r923458 - /directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/filter/SubstringNode.java

Author: kayyagari
Date: Mon Mar 15 22:04:44 2010
New Revision: 923458

URL: http://svn.apache.org/viewvc?rev=923458&view=rev
Log:
updated to use new exception

Modified:
    directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/filter/SubstringNode.java

Modified: directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/filter/SubstringNode.java
URL: http://svn.apache.org/viewvc/directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/filter/SubstringNode.java?rev=923458&r1=923457&r2=923458&view=diff
==============================================================================
--- directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/filter/SubstringNode.java (original)
+++ directory/shared/trunk/ldap/src/main/java/org/apache/directory/shared/ldap/filter/SubstringNode.java Mon Mar 15 22:04:44 2010
@@ -24,9 +24,8 @@ import java.util.ArrayList;
 import java.util.List;
 import java.util.regex.Pattern;
 
-import javax.naming.NamingException;
-
 import org.apache.directory.shared.ldap.entry.client.ClientStringValue;
+import org.apache.directory.shared.ldap.exception.LdapInvalidDnException;
 import org.apache.directory.shared.ldap.schema.Normalizer;
 import org.apache.directory.shared.ldap.util.StringTools;
 
@@ -196,9 +195,9 @@ public class SubstringNode extends LeafN
      * 
      * @param normalizer the normalizer to use for pattern component normalization
      * @return the equivalent compiled regular expression
      * @throws NamingException if there are problems while normalizing
      */
-    public final Pattern getRegex( Normalizer normalizer ) throws NamingException
+    public final Pattern getRegex( Normalizer normalizer ) throws LdapInvalidDnException
     {
         boolean isBinary = false;
@@ -196,9 +195,9 @@ public class SubstringNode extends LeafN
      * @param normalizer the normalizer to use for pattern component normalization
      * @return the equivalent compiled regular expression
-     * @throws NamingException if there are problems while normalizing
+     * @throws LdapInvalidDnException if there are problems while normalizing
      */